==> funcnodes_plotly-0.1.3-py3-none-any.whl: funcnodes_plotly/colors.py <==
import funcnodes as fn


class ContinousColorScales(fn.DataEnum):
    aggrnyl = "aggrnyl"
    agsunset = "agsunset"
    algae = "algae"
    amp = "amp"
    armyrose = "armyrose"
    balance = "balance"
    blackbody = "blackbody"
    bluered = "bluered"
    blues = "blues"
    blugrn = "blugrn"
    bluyl = "bluyl"
    brbg = "brbg"
    brwnyl = "brwnyl"
    bugn = "bugn"
    bupu = "bupu"
    burg = "burg"
    burgyl = "burgyl"
    cividis = "cividis"
    curl = "curl"
    darkmint = "darkmint"
    deep = "deep"
    delta = "delta"
    dense = "dense"
    earth = "earth"
    edge = "edge"
    electric = "electric"
    emrld = "emrld"
    fall = "fall"
    geyser = "geyser"
    gnbu = "gnbu"
    gray = "gray"
    greens = "greens"
    greys = "greys"
    haline = "haline"
    hot = "hot"
    hsv = "hsv"
    ice = "ice"
    icefire = "icefire"
    inferno = "inferno"
    jet = "jet"
    magenta = "magenta"
    magma = "magma"
    matter = "matter"
    mint = "mint"
    mrybm = "mrybm"
    mygbm = "mygbm"
    oranges = "oranges"
    orrd = "orrd"
    oryel = "oryel"
    oxy = "oxy"
    peach = "peach"
    phase = "phase"
    picnic = "picnic"
    pinkyl = "pinkyl"
    piyg = "piyg"
    plasma = "plasma"
    plotly3 = "plotly3"
    portland = "portland"
    prgn = "prgn"
    pubu = "pubu"
    pubugn = "pubugn"
    puor = "puor"
    purd = "purd"
    purp = "purp"
    purples = "purples"
    purpor = "purpor"
    rainbow = "rainbow"
    rdbu = "rdbu"
    rdgy = "rdgy"
    rdpu = "rdpu"
    rdylbu = "rdylbu"
    rdylgn = "rdylgn"
    redor = "redor"
    reds = "reds"
    solar = "solar"
    spectral = "spectral"
    speed = "speed"
    sunset = "sunset"
    sunsetdark = "sunsetdark"
    teal = "teal"
    tealgrn = "tealgrn"
    tealrose = "tealrose"
    tempo = "tempo"
    temps = "temps"
    thermal = "thermal"
    tropic = "tropic"
    turbid = "turbid"
    turbo = "turbo"
    twilight = "twilight"
    viridis = "viridis"
    ylgn = "ylgn"
    ylgnbu = "ylgnbu"
    ylorbr = "ylorbr"
    ylorrd = "ylorrd"

==> funcnodes_plotly-0.3.2-py3-none-any.whl: funcnodes_plotly/colors.py <==
import funcnodes as fn
import plotly.express as px


class ContinousColorScales(fn.DataEnum):
    aggrnyl = "aggrnyl"
    agsunset = "agsunset"
    algae = "algae"
    amp = "amp"
    armyrose = "armyrose"
    balance = "balance"
    blackbody = "blackbody"
    bluered = "bluered"
    blues = "blues"
    blugrn = "blugrn"
    bluyl = "bluyl"
    brbg = "brbg"
    brwnyl = "brwnyl"
    bugn = "bugn"
    bupu = "bupu"
    burg = "burg"
    burgyl = "burgyl"
    cividis = "cividis"
    curl = "curl"
    darkmint = "darkmint"
    deep = "deep"
    delta = "delta"
    dense = "dense"
    earth = "earth"
    edge = "edge"
    electric = "electric"
    emrld = "emrld"
    fall = "fall"
    geyser = "geyser"
    gnbu = "gnbu"
    gray = "gray"
    greens = "greens"
    greys = "greys"
    haline = "haline"
    hot = "hot"
    hsv = "hsv"
    ice = "ice"
    icefire = "icefire"
    inferno = "inferno"
    jet = "jet"
    magenta = "magenta"
    magma = "magma"
    matter = "matter"
    mint = "mint"
    mrybm = "mrybm"
    mygbm = "mygbm"
    oranges = "oranges"
    orrd = "orrd"
    oryel = "oryel"
    oxy = "oxy"
    peach = "peach"
    phase = "phase"
    picnic = "picnic"
    pinkyl = "pinkyl"
    piyg = "piyg"
    plasma = "plasma"
    plotly3 = "plotly3"
    portland = "portland"
    prgn = "prgn"
    pubu = "pubu"
    pubugn = "pubugn"
    puor = "puor"
    purd = "purd"
    purp = "purp"
    purples = "purples"
    purpor = "purpor"
    rainbow = "rainbow"
    rdbu = "rdbu"
    rdgy = "rdgy"
    rdpu = "rdpu"
    rdylbu = "rdylbu"
    rdylgn = "rdylgn"
    redor = "redor"
    reds = "reds"
    solar = "solar"
    spectral = "spectral"
    speed = "speed"
    sunset = "sunset"
    sunsetdark = "sunsetdark"
    teal = "teal"
    tealgrn = "tealgrn"
    tealrose = "tealrose"
    tempo = "tempo"
    temps = "temps"
    thermal = "thermal"
    tropic = "tropic"
    turbid = "turbid"
    turbo = "turbo"
    twilight = "twilight"
    viridis = "viridis"
    ylgn = "ylgn"
    ylgnbu = "ylgnbu"
    ylorbr = "ylorbr"
    ylorrd = "ylorrd"


class DiscreteColorScales(fn.DataEnum):
    set1 = px.colors.qualitative.Set1
    pastel1 = px.colors.qualitative.Pastel1
    dark2 = px.colors.qualitative.Dark2
    set2 = px.colors.qualitative.Set2
    pastel2 = px.colors.qualitative.Pastel2
    set3 = px.colors.qualitative.Set3
    antique = px.colors.qualitative.Antique
    bold = px.colors.qualitative.Bold
    pastel = px.colors.qualitative.Pastel
    prism = px.colors.qualitative.Prism
    safe = px.colors.qualitative.Safe
    vivid = px.colors.qualitative.Vivid
    alphabet = px.colors.qualitative.Alphabet
    d3 = px.colors.qualitative.D3
    dark24 = px.colors.qualitative.Dark24
    g10 = px.colors.qualitative.G10
    light24 = px.colors.qualitative.Light24
    plotly = px.colors.qualitative.Plotly
    t10 = px.colors.qualitative.T10
